#
# spec file for package xclip
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rversion 0.13
%define gitdate 20220129
%define githash b372f73579d30f9ba998ffd0a73694e7abe2c313

Name:           xclip
VCS: https://src.suse.de/SLFO-pool/xclip#213e22a31d288269360cdeea9c47a43c64f66845e5b4f906c633e8568e011637
Version:        %{rversion}+git%{gitdate}
Release:        160000.1.3
Summary:        Command Line Interface to the X11 Clipboard
License:        GPL-2.0-or-later
Group:          System/X11/Utilities
URL:            https://github.com/astrand/xclip
Source:         https://github.com/astrand/xclip/archive/%{githash}.tar.gz#/%{name}-%{githash}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xmu)

%description
xclip is a command line interface to the X11 clipboard. It can also be used
for copying files, as an alternative to sftp/scp, thus avoiding password
prompts when X11 forwarding has already been setup.

%prep
%autosetup -n %{name}-%{githash}

%build
bash ./bootstrap
%configure \
	 --x-includes="%{_usr}/include" \
	 --x-libraries="%{_usr}/%{_lib}" \
	 --with-x
%make_build

%install
%make_install

%check

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/xclip
%{_bindir}/xclip-copyfile
%{_bindir}/xclip-cutfile
%{_bindir}/xclip-pastefile
%{_mandir}/man1/xclip.1%{?ext_man}*
%{_mandir}/man1/xclip-copyfile.1%{?ext_man}*

%changelog
* Fri Jun 21 2024 manfred99@gmx.ch
- use git hash in download URL, not branch name.
* Tue Jun 18 2024 manfred99@gmx.ch
- Update to master checkout b372f73:
  * add -sensitive option
  * works reliably for large data streams
  * improved debug and checking facilities
  * when pasting, don't clear selection unless -sensitive is given
  * if stdin is a tty, choose appropriate -i or -o option as default mode
  * numerous bug fixes (segfaults, resource leaks, null pointer dereference)
* Fri Mar 12 2021 dmueller@suse.com
- modernise spec-file (move license to licensedir)
* Sat Apr 22 2017 mimi.vx@gmail.com
- change homepage and download url to github
* Thu Apr 13 2017 hpj@urpla.net
- Update to 0.13:
  * Add the remove-last-newline option
  * Fix the compile warning & build steps, and add .gitignore
  * An new option "-rmlastnl" is added to remove the last newline
    character if present.
  * Before running ./configure, autoreconf is required to generate
    configuration files.
  * Add .gitignore
  * Changing Sourceforge URLs to GitHub.
  * don't treat TARGETS request as contents request
  * Document the -noutf8 option.
  * Minor lang corrections.
  * Avoid warnings about unused variable; only define html if
    HAVE_ICONV.
  * Applied 2924602 - 0005-Added-a-target-command-line-option.patch
  * Applied 2924602 - 0004-Improved-xclip-s-error-handling.patch
  * Applied 2924602 - 0003-Added-support-for-printing-more-data-types.patch
  * Applied 2924602 - 0002-Added-support-in-xcout-for-receiving-16-and-32-bit-d.patch
  * Applied 2924602 - 0001-Added-a-parameter-to-xcout-which-receives-the-type-o.patch
* Thu Sep 10 2015 mpluskal@suse.com
- Update to 0.12
  * Build fixes: Check for Xmu and Xt
  * The version number has been corrected.
  * Man pages are now available. Contributed by Maximilian Gass.
- Cleanup spec file with spec-cleaner
* Mon Dec 12 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Aug 27 2009 coolo@novell.com
- update to 0.11 from build service
    xclip-copyfile is now compatible with recent tar versions.
    The performance has been greatly enhanced, especially over
    slow networks. Two helper scripts, xclip-copyfile and
    xclip-pastefile, has been added. Taken together, xclip can now
    be used as an alternative to sftp/scp, thus avoiding password
    prompt when X11 forwarding has already been setup.
    Autoconf is now used instead of Imake.
* Thu Aug  7 2008 bphilips@suse.de
- Initial commit 0.08
